# Common utils for deep learning

[![build](https://github.com/ultmaster/utilsd/actions/workflows/python-test.yml/badge.svg)](https://github.com/ultmaster/utilsd/actions/workflows/python-test.yml)

```
pip install utilsd
```

### What is utilsd?

I'm collecting *common utils* that are used in at least 2 of the projects I have been working on. I expect most of the utils are in the corner of logging, experiment setup, config management, log analysis, and etc. As I almost always use PyTorch and most of the projects are featuring vision tasks, it will be built upon PyTorch.

### Why it is named utilsd?

To join the D-universe that is powered by several ambitious system researchers.

### Is it a stable toolkit I can use?

Not really. It is still a draft and being tested against multiple internal projects. I will try to write documentation for this project within a couple of months (or give up on it forever).
